summaryrefslogtreecommitdiff
path: root/addons/web/static/src/js/views/basic/basic_renderer.js
diff options
context:
space:
mode:
authorAdrian Torres <adt@odoo.com>2018-11-16 10:16:54 +0000
committerAdrian Torres <adt@odoo.com>2018-11-20 10:51:07 +0000
commit407f6e35321eeeadeb8f56207475bf77d13b2fc7 (patch)
tree02453e27db9e7cec0316190c3b7736cabb49d66b /addons/web/static/src/js/views/basic/basic_renderer.js
parentedfcee019005fd3e7f99cff5074c360fbc53dc93 (diff)
[FIX] stock: do not prefetch stock.move fields
For a SO of 300 lines, when confirmed, it takes 195s to process stock moves for the SO, which is an insane amount of time for any kind of process in Odoo. This happens because stock.move is a heavy model with lots of fields, prefetching all these fields at once can hinder performance when processing a lot of stock.moves. To reduce the processing time, the prefetching is disabled in the specific scenario of processing stock moves and pickings on SO confirmation. This patch increases the performance of SO validation (with stock installed) by ~30%. Pre-patch: 195s (300 SOL) Post-patch: 135s (300 SOL) closes odoo/odoo#28835
Diffstat (limited to 'addons/web/static/src/js/views/basic/basic_renderer.js')
0 files changed, 0 insertions, 0 deletions